@@ -4,7 +4,7 @@ import scipy.sparse as sp
 from sklearn.utils.fixes import loguniform
 from sklearn.utils.validation import check_random_state
 
-from cca_zoo import cross_validate, permutation_test_score, learning_curve
+from cca_zoo import cross_validate, permutation_test_score, learning_curve, PRCCA, GRCCA
 from cca_zoo.data import linear_simulated_data
 from cca_zoo.model_selection import GridSearchCV, RandomizedSearchCV
 from cca_zoo.models import (
@@ -27,8 +27,6 @@ from cca_zoo.models import (
     PLS_ALS,
     SCCA_ADMM,
     SCCA_Parkhomenko,
-    StochasticPowerPLS,
-    IncrementalPLS,
 )
 from cca_zoo.plotting import pairplot_train_test
 
@@ -68,31 +66,28 @@ def test_unregularized_methods():
 def test_unregularized_multi():
     # Tests unregularized CCA methods for more than 2 views. The idea is that all of these should give the same result.
     latent_dims = 2
-    cca = rCCA(latent_dims=latent_dims).fit((X, Y, Z))
     gcca = GCCA(latent_dims=latent_dims).fit((X, Y, Z))
     mcca = MCCA(latent_dims=latent_dims).fit((X, Y, Z))
     kcca = KCCA(latent_dims=latent_dims).fit((X, Y, Z))
-    corr_cca = cca.score((X, Y, Z))
     corr_gcca = gcca.score((X, Y, Z))
     corr_mcca = mcca.score((X, Y, Z))
     corr_kcca = kcca.score((X, Y, Z))
     # Check the correlations from each unregularized method are the same
-    assert np.testing.assert_array_almost_equal(corr_cca, corr_mcca, decimal=1) is None
-    assert np.testing.assert_array_almost_equal(corr_cca, corr_gcca, decimal=1) is None
-    assert np.testing.assert_array_almost_equal(corr_cca, corr_kcca, decimal=1) is None
+    assert np.testing.assert_array_almost_equal(corr_mcca, corr_gcca, decimal=1) is None
+    assert np.testing.assert_array_almost_equal(corr_mcca, corr_kcca, decimal=1) is None
 
 
 def test_regularized_methods():
     # Test that linear regularized methods match PLS solution when using maximum regularisation.
     latent_dims = 2
     c = 1
+    rcca = rCCA(latent_dims=latent_dims, c=[c, c]).fit([X, Y])
+    mcca = MCCA(latent_dims=latent_dims, c=[c, c]).fit([X, Y])
+    pls = PLS(latent_dims=latent_dims).fit([X, Y])
+    gcca = GCCA(latent_dims=latent_dims, c=[c, c]).fit([X, Y])
     kernel = KCCA(latent_dims=latent_dims, c=[c, c], kernel=["linear", "linear"]).fit(
         (X, Y)
     )
-    pls = PLS(latent_dims=latent_dims).fit([X, Y])
-    gcca = GCCA(latent_dims=latent_dims, c=[c, c]).fit([X, Y])
-    mcca = MCCA(latent_dims=latent_dims, c=[c, c]).fit([X, Y])
-    rcca = rCCA(latent_dims=latent_dims, c=[c, c]).fit([X, Y])
     corr_gcca = gcca.score((X, Y))
     corr_mcca = mcca.score((X, Y))
     corr_kernel = kernel.score((X, Y))
@@ -221,6 +216,8 @@ def test_partialcca():
 
 
 def test_stochastic():
+    torch = pytest.importorskip("torch")
+    from cca_zoo.models import StochasticPowerPLS, IncrementalPLS
     pls = PLS(latent_dims=1).fit((X, Y))
     ipls = IncrementalPLS(latent_dims=1, epochs=10, simple=False, batch_size=1).fit(
         (X, Y)
@@ -254,6 +251,33 @@ def test_plotting():
     pairplot_train_test(pls.transform((X, Y)), pls.transform((X_te, Y_te)))
 
 
+def test_PRCCA():
+    # Test that PRCCA works
+    prcca = PRCCA(latent_dims=2, c=[0, 0]).fit((X, Y), idxs=(np.arange(10), np.arange(11)))
+    cca = CCA(latent_dims=2).fit([X, Y])
+    assert np.testing.assert_array_almost_equal(cca.score((X, Y)), prcca.score((X, Y)), decimal=1) is None
+    prcca = PRCCA(latent_dims=2, c=[1, 1]).fit((X, Y), idxs=(np.arange(10), np.arange(11)))
+    pls = PLS(latent_dims=2).fit([X, Y])
+    assert np.testing.assert_array_almost_equal(pls.score((X, Y)), prcca.score((X, Y)), decimal=1) is None
+
+
+def test_GRCCA():
+    feature_group_1 = np.zeros(X.shape[1], dtype=int)
+    feature_group_1[:3] = 1
+    feature_group_1[3:6] = 2
+    feature_group_2 = np.zeros(Y.shape[1], dtype=int)
+    feature_group_2[:3] = 1
+    feature_group_2[3:6] = 2
+    feature_group_3 = np.zeros(Z.shape[1], dtype=int)
+    feature_group_3[:3] = 1
+    feature_group_3[3:6] = 2
+    # Test that GRCCA works
+    grcca = GRCCA(latent_dims=1, c=[100, 0], mu=0).fit((X, Y), feature_groups=[feature_group_1, feature_group_2])
+    grcca.score((X, Y))
+    grcca.transform((X, Y))
+    grcca = GRCCA(c=[100, 0, 50]).fit((X, Y, Z), feature_groups=[feature_group_1, feature_group_2, feature_group_3])
+
+
 def test_PCCA():
     # some might not have access to jax/numpyro so leave this as an optional test locally.
     numpyro = pytest.importorskip("numpyro")
