@@ -9,7 +9,7 @@ permutation testing, learning curves, and cross-validation.
 import numpy as np
 
 from cca_zoo import CCA, learning_curve
-from cca_zoo.data import generate_covariance_data
+from cca_zoo.data import linear_simulated_data
 import matplotlib.pyplot as plt
 
 # %%
@@ -21,8 +21,8 @@ p = 15
 q = 15
 latent_dims = 3
 
-(X, Y), (tx, ty) = generate_covariance_data(
-    n, view_features=[p, q], latent_dims=latent_dims, correlation=[0.9,0.5,0.1]
+(X, Y), (tx, ty) = linear_simulated_data(
+    n, view_features=[p, q], latent_dims=latent_dims, correlation=[0.9, 0.5, 0.1]
 )
 
 # %%
@@ -61,14 +61,14 @@ import matplotlib.pyplot as plt
 
 
 def plot_learning_curve(
-        estimator,
-        title,
-        views,
-        axes=None,
-        ylim=None,
-        cv=None,
-        n_jobs=None,
-        train_sizes=np.linspace(0.1, 1.0, 5),
+    estimator,
+    title,
+    views,
+    axes=None,
+    ylim=None,
+    cv=None,
+    n_jobs=None,
+    train_sizes=np.linspace(0.1, 1.0, 5),
 ):
     """
     Generate 3 plots: the test and training learning curve, the training
